using System;
using System.Collections.Generic;
using System.Text;
using SWConfigDataClientLib;
using SWConfigDataClientLib.Data;
using SWConfigDataClientLib.Proxies.Users;
using SWConfigDataSharedLib.Exceptions;
using IpPbx.Samples.Shared;

namespace IpPbx.EditUser
{
    class Program
    {
        private static CDSLib cdsLib;

        //------------------------------------------------------------------------------
        
        static int Main(string[] args)
        {
            try
            {
                if (args.Length == 3)
                {
                    // Connected to remote server with UsernamePassword Authentication            
                    Program.cdsLib = new CDSLib(args[0], args[1], args[2]);
                }
                else if (args.Length == 2)
                {
                    // Connected to local server with UsernamePassword Authentication            
                    Program.cdsLib = new CDSLib(args[0], args[1]);
                }
                else if (args.Length == 1)
                {
                    // Connected to remote server with Windows Authentication
                    Program.cdsLib = new CDSLib(args[0]);
                }
                else
                {
                    // Connected to local server with Windows Authentication            
                    Program.cdsLib = new CDSLib();
                }
                
                // Check if a CDS connection can be established
                // The use of this method is not mandatory.
                if (!Program.cdsLib.TestConnection())
                {
                    Console.WriteLine("Connection Test for Server '{0}' failed", Program.cdsLib.ServerName);
                    Console.WriteLine("Press any key to proceed...");
                    Console.ReadLine();
                    return -1;
                }

                // Ask for username
                Console.Write("Please enter a username: ");
                string username = Console.ReadLine();

                // Ask for a new comment text
                Console.Write("Please enter the new comment for the user: ");
                string comment = Console.ReadLine();

                // Update user object with update call
                Program.cdsLib.EditUserCommentForOneUser(username, comment);

                // If you want to update multiple user objects at once
                // you should use the following implementation:
                // Program.cdsLib.EditUserCommentForAllUsers(comment);

                Console.WriteLine("Process completed");
                Console.WriteLine("Press any key to proceed...");
                return 0;   
            }
            catch (Exception exception)
            {
                Console.WriteLine("Exception catched: {0}", exception);
                Console.ReadLine();
            }

            return -1;
        }
        
        //------------------------------------------------------------------------------
    }
}
