﻿using System;
using System.IO;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using SWConfigDataClientLib;
using SWConfigDataClientLib.Proxies.Admin;
using SWConfigDataClientLib.Proxies.Files;
using SWConfigDataClientLib.Proxies.PhoneClient;
using SWConfigDataSharedLib.Exceptions;
using IpPbx.Samples.Shared;

namespace IpPbx.FileDemo
{
    public partial class frmMain : Form
    {
        private CDSLib cdsLib;
        private FileListEntrySortableCollection skinList;

        //------------------------------------------------------------------------------------

        public frmMain()
        {
            InitializeComponent();
        }
              
        //------------------------------------------------------------------------------------

        private void cmdLogin_Click(object sender, EventArgs e)
        {
            this.cdsLib = new CDSLib(txtName.Text,
                                     txtPassword.Text,
                                     txtServer.Text);

            if (this.cdsLib.TestConnection())
            {
                txtName.Enabled = false;
                txtPassword.Enabled = false;
                txtServer.Enabled = false;
                cmdLogin.Enabled = false;
                cmdLoadSkins.Enabled = true;
                cbxSkinList.Enabled = true;
            }
            else
            {
                MessageBox.Show("Connection failed", "Error",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        //------------------------------------------------------------------------------------

        private void cmdLoadSkins_Click(object sender, EventArgs e)
        {
            try
            {
                cbxSkinList.Items.Clear();

                skinList = cdsLib.GetSkins();

                // Add skins to combobox
                foreach (FileListEntry entry in skinList)
                {
                    cbxSkinList.Items.Add(entry.Name);
                }

                // Select first skin in the combobox
                if (cbxSkinList.Items.Count > 0)
                {
                    cbxSkinList.SelectedIndex = 0;
                }

                cmdLoadSkins.Enabled = false;
                cmdDownloadSkin.Enabled = true;
                cmdUploadSkin.Enabled = true;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Exception",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        //------------------------------------------------------------------------------------

        private void cmdDownloadSkin_Click(object sender, EventArgs e)
        {
            try
            {
                SaveFileDialog dialog = new SaveFileDialog();
                dialog.FileName = cbxSkinList.Text;
                dialog.Filter = "Skin files|*.cab|All files|*.*";
                DialogResult res = dialog.ShowDialog();
                
                if (res == DialogResult.OK)
                {
                    FileListEntry fileEntry = skinList[cbxSkinList.SelectedIndex];

                    string localTempFilePath = cdsLib.GetFile(fileEntry);

                    File.Copy(localTempFilePath, dialog.FileName);
                    File.SetAttributes(dialog.FileName, FileAttributes.Normal);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Exception",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        //------------------------------------------------------------------------------------

        private void cmdUploadSkin_Click(object sender, EventArgs e)
        {
            try
            {
                OpenFileDialog dialog = new OpenFileDialog();
                dialog.Filter = "Skin files|*.cab|All files|*.*";
                DialogResult res = dialog.ShowDialog();

                if (res == DialogResult.OK)
                {
                    cdsLib.AddSkin(dialog.SafeFileName, dialog.FileName);

                    this.cmdLoadSkins_Click(null, null);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Exception",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
                
        //------------------------------------------------------------------------------------        
    }
}
