﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using System.Web.Security;
using IpPbx.WebApplication.Models;
using IpPbx.Samples.Shared;
using SWConfigDataSharedLib.Tracing;

namespace IpPbx.WebApplication.Controllers
{
    public class AccountController : Controller
    {
        #region Tracing

        // Init user defined trace module named "CDSlib"
        // See Web.config for trace module configuration
        private static STraceInfo classTrace = new STraceInfo(new System.Diagnostics.TraceSwitch(
                                                              "AccountCt", "AccountCt", "2"),
                                                              typeof(AccountController));

        #endregion

        #region Web Methods

        // GET: /Account/LogOn
        public ActionResult LogOn()
        {
            classTrace.TraceVerbose("LogOn", "()");
            return View();
        }

        // POST: /Account/LogOn
        [HttpPost]
        public ActionResult LogOn(LogOnModel model, string returnUrl)
        {
            classTrace.TraceVerbose("LogOn", "(LogOnModel / String)");

            if (ModelState.IsValid)
            {
                // This is just a quick demo implementation
                // You should use a Membership Provider here
                CDSLib cdsLib = new CDSLib(model.UserName,
                                           model.Password,
                                           model.ServerAddress);

                classTrace.TraceVerbose("LogOn", "Checking if user credentials are valid...");

                if (cdsLib.TestConnection())
                {
                    classTrace.TraceVerbose("LogOn", "CDS Connection was successful. Credentials are valid.");

                    Session["IsAuthenticated"] = true;
                    Session["Username"] = model.UserName;
                    Session["LoginData"] = model;

                    if (Url.IsLocalUrl(returnUrl) && returnUrl.Length > 1 && returnUrl.StartsWith("/")
                        && !returnUrl.StartsWith("//") && !returnUrl.StartsWith("/\\"))
                    {
                        classTrace.TraceVerbose("LogOn", "Redirecting to '{0}'", returnUrl);
                        return Redirect(returnUrl);
                    }
                    else
                    {
                        classTrace.TraceVerbose("LogOn", "Redirecting to Index page");
                        return RedirectToAction("Index", "Home");
                    }
                }
                else
                {
                    classTrace.TraceError("LogOn", "The provided user name or password is not valid. Access denied.");
                    ModelState.AddModelError("", "The provided user name or password is not valid. Access denied.");
                }
            }
            
            // If we got this far, something failed, redisplay form
            return View(model);
        }

        // GET: /Account/LogOff
        public ActionResult LogOff()
        {
            classTrace.TraceVerbose("LogOff", "()");

            Session["IsAuthenticated"] = false;
            Session["Username"] = String.Empty;
            Session["LoginData"] = null;

            return RedirectToAction("Index", "Home");
        }

        #endregion

        #region Status Codes

        private static string ErrorCodeToString(MembershipCreateStatus createStatus)
        {
            // See http://go.microsoft.com/fwlink/?LinkID=177550 for
            // a full list of status codes.
            switch (createStatus)
            {
                case MembershipCreateStatus.DuplicateUserName:
                    return "User name already exists. Please enter a different user name.";

                case MembershipCreateStatus.DuplicateEmail:
                    return "A user name for that e-mail address already exists. Please enter a different e-mail address.";

                case MembershipCreateStatus.InvalidPassword:
                    return "The password provided is invalid. Please enter a valid password value.";

                case MembershipCreateStatus.InvalidEmail:
                    return "The e-mail address provided is invalid. Please check the value and try again.";

                case MembershipCreateStatus.InvalidAnswer:
                    return "The password retrieval answer provided is invalid. Please check the value and try again.";

                case MembershipCreateStatus.InvalidQuestion:
                    return "The password retrieval question provided is invalid. Please check the value and try again.";

                case MembershipCreateStatus.InvalidUserName:
                    return "The user name provided is invalid. Please check the value and try again.";

                case MembershipCreateStatus.ProviderError:
                    return "The authentication provider returned an error. Please verify your entry and try again. If the problem persists, please contact your system administrator.";

                case MembershipCreateStatus.UserRejected:
                    return "The user creation request has been canceled. Please verify your entry and try again. If the problem persists, please contact your system administrator.";

                default:
                    return "An unknown error occurred. Please verify your entry and try again. If the problem persists, please contact your system administrator.";
            }
        }

        #endregion
    }
}
